@@ -11,6 +11,16 @@ class HMAC:
     def __init__(self, secret):
         self.secret = secret
 
+    def hash512(self, data):
+        """
+        Hashes the given string data.
+        """
+        key = self.secret.encode("UTF-8")
+        msg = data.encode("UTF-8")
+
+        dig = hmac.new(key, msg=msg, digestmod=hashlib.sha512).hexdigest()
+        return base64.b64encode(dig.encode("utf-8")).decode()
+
     def hash(self, data):
         """
         Hashes the given string data.
