@@ -3,11 +3,14 @@ from gaia_sdk.graphql.request.type.Behaviour import Behaviour
 
 from typing import Callable, List
 from gaia_sdk.api.VariableRegistry import VariableRegistry
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
 
 
 class UpdatedBehaviourImpulse(list):
     """
-    Impulse which indicates the resulf of a update behaviour impulse
+    Impulse which indicates the result of a update behaviour impulse
     """
 
     def id(self):
